pub enum EventArray {
Logs(LogArray),
Metrics(MetricArray),
Traces(TraceArray),
}Expand description
An array of one of the Event variants exclusively.
Variants
Logs(LogArray)
An array of type LogEvent
Metrics(MetricArray)
An array of type Metric
Traces(TraceArray)
An array of type TraceEvent
Implementations
Sourceimpl EventArray
impl EventArray
Sourcepub fn iter_events(&self) -> impl Iterator<Item = EventRef<'_>>
pub fn iter_events(&self) -> impl Iterator<Item = EventRef<'_>>
Iterate over references to this array’s events.
Sourcepub fn iter_events_mut(&mut self) -> impl Iterator<Item = EventMutRef<'_>>
pub fn iter_events_mut(&mut self) -> impl Iterator<Item = EventMutRef<'_>>
Iterate over mutable references to this array’s events.
Sourcepub fn iter_logs_mut(&mut self) -> impl Iterator<Item = &mut LogEvent>
pub fn iter_logs_mut(&mut self) -> impl Iterator<Item = &mut LogEvent>
Iterate over references to the logs in this array.
Sourcepub fn for_each_metadata_mut(&mut self, f: impl FnMut(&mut EventMetadata))
pub fn for_each_metadata_mut(&mut self, f: impl FnMut(&mut EventMetadata))
Applies a closure to each event’s metadata in this array.